(function (Drupal, DrupalSettings) {

  /**
   * Override loadObject method.
   *
   * @param entries
   * @param observer
   */
  Drupal.behaviors.lazyImageStyle.loadObjects = function (entries, observer) {
    entries.forEach (function (entry) {
      if (entry.isIntersecting) {
        entry.target.src = entry.target.dataset.src;
        // Remove blue class if found.
        if (entry.target.classList.contains('blue')) {
          entry.target.classList.remove('blue');
        }
        observer.unobserve(entry.target);
      }
    })
  };

  /**
   * Override attach behavior method.
   *
   * @param context
   * @param settings
   */
  Drupal.behaviors.lazyImageStyle.attach = function (context, settings) {
    let imgs = this.getObjects();
    let offset = Number(this.getConfig('offset', 100));
    let options = {
      rootMargin: `${offset}px`,
      threshold: 1.0
    };
    this.observer = new IntersectionObserver(this.loadObjects, options);
    imgs.forEach(image => {
      this.observer.observe(image);
    })
  };

}(Drupal, drupalSettings));